import axios from "axios";
import { Toast } from "vant";
import store from "@/store";
import { getToken } from "@/utils/auth";

const successCode = 200000;
// create an axios instance
const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API, // url = base url + request url
  // baseURL: "", // url = base url + request url
  // withCredentials: true, // send cookies when cross-domain requests
  timeout: 20000, // request timeout
});

// request interceptor
service.interceptors.request.use(
  (config) => {
    // do something before request is sent
    let token = getToken();
    if (token) {
      // let each request carry token
      // ['X-Token'] is a custom headers key
      // please modify it according to the actual situation
      config.headers["token"] = token;
    }
    return config;
  },
  (error) => {
    // do something with request error
    console.log(error); // for debug
    return Promise.reject(error);
  }
);

// response interceptor
service.interceptors.response.use(
  /**
   * If you want to get http information such as headers or status
   * Please return  response => response
   */

  /**
   * Determine the request status by custom code
   * Here is just an example
   * You can also judge the status by HTTP Status Code
   */
  (response) => {
    const res = response.data;
    console.log(res);
    // if the custom code is not 20000, it is judged as an error.
    if (res.code !== successCode) {
      // 50008: Illegal token; 50012: Other clients logged in; 50014: Token expired;
      if (
        res.code === 403 ||
        res.code === 50012 ||
        res.code === 50014 ||
        res.code === 200201
      ) {
        // to re-login
        Toast.fail("登录已经过期");
        setTimeout(() => {
          store.dispatch("user/resetToken").then(() => {
            location.reload();
          });
        }, 2000);
        //   .then(() => {
        //   store.dispatch("user/resetToken").then(() => {
        //     location.reload();
        //   });
        // });
      } else {
        Toast(res.msg || "Error");
      }
      return Promise.reject(new Error(res.errmsg || "Error"));
    } else {
      return res;
    }
  },
  (error) => {
    // console.log("err" + error); // for debug
    if (error.response.status === 500) {
      Message({
        message: "服务器错误",
        type: "error",
        duration: 5 * 1000,
      });
    } else {
      Message({
        message: error,
        type: "error",
        duration: 5 * 1000,
      });
    }
    return Promise.reject(error);
  }
);

export default service;
